### R code from vignette source 'penalized.Rnw'

###################################################
### code chunk number 1: options
###################################################
options(continue = "  ")


###################################################
### code chunk number 2: load
###################################################
library(penalized)
library(survival)
data(nki70)


###################################################
### code chunk number 3: setseed
###################################################
set.seed(1)


###################################################
### code chunk number 4: first
###################################################
fit <- penalized(ER, ~DIAPH3+NUSAP1, data=nki70, lambda2=1)
fit <- penalized(ER, nki70[,10:11], data=nki70, lambda2=1)
fit <- penalized(ER~DIAPH3+NUSAP1, data=nki70, lambda2=1)


###################################################
### code chunk number 5: survival
###################################################
fit <- penalized(Surv(time,event)~DIAPH3+NUSAP1, data=nki70, lambda2=1)


###################################################
### code chunk number 6: attach
###################################################
attach(nki70)


###################################################
### code chunk number 7: elastic net
###################################################
fit <- penalized(Surv(time,event)~DIAPH3+NUSAP1, data=nki70, lambda1=1, lambda2=1)


###################################################
### code chunk number 8: vector lambda
###################################################
fit <- penalized(Surv(time,event)~DIAPH3+NUSAP1, data=nki70, lambda2=c(1,2))


###################################################
### code chunk number 9: extract
###################################################
residuals(fit)[1:10]
fitted(fit)[1:10]
basesurv(fit)


###################################################
### code chunk number 10: coefficients
###################################################
coefficients(fit, "all")


###################################################
### code chunk number 11: loglik_penalty
###################################################
loglik(fit)
penalty(fit)


###################################################
### code chunk number 12: predict
###################################################
predict(fit, ~DIAPH3+NUSAP1, data=nki70[1:3,])
predict(fit, nki70[1:3,c("DIAPH3","NUSAP1")])


###################################################
### code chunk number 13: predict_survival
###################################################
pred <- predict(fit, nki70[1:3,c("DIAPH3","NUSAP1")])
survival(pred, time=5)


###################################################
### code chunk number 14: weights
###################################################
coefficients(fit)
coefficients(fit, standardize = TRUE)
weights(fit)


###################################################
### code chunk number 15: unpenalized
###################################################
fit <- penalized(Surv(time,event), nki70[,8:77], ~ER, lambda2=1)
fit <- penalized(Surv(time,event)~ER, nki70[,8:77], lambda2=1)


###################################################
### code chunk number 16: steps
###################################################
fit <- penalized(Surv(time,event), nki70[,8:77], lambda1=1,
    steps=50, trace = FALSE)
plotpath(fit, log="x")


###################################################
### code chunk number 17: steps park
###################################################
fit <- penalized(Surv(time,event), nki70[,8:77], lambda1=1,
    steps="Park", trace = FALSE)


###################################################
### code chunk number 18: stepsplot
###################################################
plotpath(fit, log="x")


###################################################
### code chunk number 19: positive
###################################################
fit <- penalized(Surv(time,event), nki70[,8:77], positive=TRUE)


###################################################
### code chunk number 20: positivecoefficients
###################################################
coefficients(fit)


###################################################
### code chunk number 21: positivestepsplot
###################################################
fit <- penalized(Surv(time,event), nki70[,8:77], positive=TRUE,
    steps=50)
plotpath(fit)


###################################################
### code chunk number 22: partpositive
###################################################
coef(penalized(Surv(time,event), nki70[,8:16], positive=c(F,rep(T,8))))


###################################################
### code chunk number 23: globaltest_install (eval = FALSE)
###################################################
## source("http://bioconductor.org/biocLite.R")
## biocLite("globaltest")


###################################################
### code chunk number 24: globaltest
###################################################
library(globaltest)
gt(Surv(time,event), nki70[,8:77])


###################################################
### code chunk number 25: cvl1
###################################################
fit <- cvl(Surv(time,event), nki70[,8:77], lambda1=1, fold=10)


###################################################
### code chunk number 26: cvl2
###################################################
fit$cvl
fit$fullfit


###################################################
### code chunk number 27: cvl3
###################################################
fit <- cvl(Surv(time,event), nki70[,8:77], lambda1=2, fold=fit$fold)


###################################################
### code chunk number 28: cvlappr1
###################################################
fit1 <- cvl(Surv(time,event), nki70[,8:77], lambda2=10)


###################################################
### code chunk number 29: cvlappr2
###################################################
fit1$cvl


###################################################
### code chunk number 30: cvlappr3
###################################################
fit2 <- cvl(Surv(time,event), nki70[,8:77], lambda2=10, approximate=TRUE)


###################################################
### code chunk number 31: cvlappr4
###################################################
fit2$cvl


###################################################
### code chunk number 32: breslow
###################################################
fit$predictions
time(fit$predictions)
as.data.frame(basesurv(fit$fullfit))[1:10,]
plot(fit$predictions)


###################################################
### code chunk number 33: breslowplot
###################################################
plot(fit$predictions)


###################################################
### code chunk number 34: cv-survival
###################################################
survival(fit$predictions, 5)[1:10]


###################################################
### code chunk number 35: prof
###################################################
fit1 <- profL1(Surv(time,event), nki70[,50:70], fold=10, plot=TRUE)
fit2 <- profL2(Surv(time,event), nki70[,50:70], fold=fit1$fold,
    minl = 0.01, maxl = 1000)
plot(fit2$lambda, fit2$cvl, type="l", log="x")


###################################################
### code chunk number 36: profplot1
###################################################
plot(fit1$lambda, fit1$cvl, type="l")


###################################################
### code chunk number 37: profplot2
###################################################
plot(fit2$lambda, fit2$cvl, type="l", log="x")


###################################################
### code chunk number 38: profpath
###################################################
plotpath(fit2$fullfit, log="x")


###################################################
### code chunk number 39: profpathplot
###################################################
plotpath(fit2$fullfit, log="x")


###################################################
### code chunk number 40: opt1
###################################################
opt1 <- optL1(Surv(time,event), nki70[,50:70], fold=fit1$fold)


###################################################
### code chunk number 41: optres
###################################################
opt1$lambda
opt1$cvl


###################################################
### code chunk number 42: opt2
###################################################
opt2 <- optL2(Surv(time,event), nki70[,50:70], fold=fit2$fold)


